/*!
 * Bootstrap Icons v1.13.1 (https://icons.getbootstrap.com/)
 * Copyright 2019-2024 The Bootstrap Authors
 * Licensed under MIT (https://github.com/twbs/icons/blob/main/LICENSE)
 */

${{ name }}-font: "{{ name }}" !default;
${{ name }}-font-dir: "{{ fontsUrl }}" !default;
${{ name }}-font-file: "#{${{ name }}-font-dir}/#{${{ name }}-font}" !default;
${{ name }}-font-hash: "24e3eb84d0bcaf83d77f904c78ac1f47" !default;
${{ name }}-font-src: url("#{${{ name }}-font-file}.woff2?#{${{ name }}-font-hash}") format("woff2"),
                           url("#{${{ name }}-font-file}.woff?#{${{ name }}-font-hash}") format("woff") !default;

@font-face {
  font-display: block;
  font-family: ${{ name }}-font;
  src: ${{ name }}-font-src;
}

.{{ prefix }}::before,
[class^="{{ prefix }}-"]::before,
[class*=" {{ prefix }}-"]::before {
  display: inline-block;
  font-family: ${{ name }}-font !important;
  font-style: normal;
  font-weight: normal !important;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  vertical-align: -.125em;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

${{ name }}-map: (
{{# each codepoints }}
  "{{ @key }}": "\\{{ codepoint this }}",
{{/ each }}
);

@each $icon, $codepoint in ${{ name }}-map {
  .{{ prefix }}-#{$icon}::before { content: $codepoint; }
}
